%global pypi_name astropy

Name:           python-astropy
Version:        7.0.0
Release:        %mkrel 1
Group:          Sciences/Astronomy
Summary:        Community-developed python astronomy tools

License:        BSD
URL:            https://www.astropy.org/
Source0:        https://pypi.org/project/astropy/%{pypi_source}
Patch0:         python-astropy-system-configobj.patch
Patch1:         astropy-6.1.0-system-ply.patch
Patch2:         astropy-6.1.0-linking.patch

BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  expat-devel
BuildRequires:  wcslib-devel >= 8.2.2

#(eatdirt) manual to workaround too strict versionning
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(extension-helpers)
BuildRequires:  python3dist(numpy)
BuildRequires:  python3dist(setuptools-scm)

%description
Astropy is a package intended to contain core functionality and some
common tools needed for performing astronomy and astrophysics research
with Python. It also provides an index for other astronomy packages
and tools for managing them.

%package -n python3-%{pypi_name}
Summary:        Community-developed python astronomy tools
Requires:       python3dist(numpy)
Requires:       python3dist(configobj)
Requires:       python3dist(ply)
%{?python_provide:%python_provide python3-%{pypi_name}}
Provides:       bundled(jquery) = 3.11

%description -n python3-%{pypi_name}
Astropy is a package intended to contain core functionality and some
common tools needed for performing astronomy and astrophysics research
with Python. It also provides an index for other astronomy packages
and tools for managing them.

%package -n %{pypi_name}-tools
Summary:        Astropy utility tools
BuildArch:      noarch
Requires:       python3dist(astropy) >= 6

%description -n %{pypi_name}-tools
Utilities provided by Astropy: 'volint' for validating a Virtual Observatory
files, 'wcslint' for validating the WCS keywords in a FITS file.

%prep
%autosetup -n %{pypi_name}-%{version} -p1

# Force Cython re-run
echo "cython_version = 'unknown'" > astropy/cython_version.py

# Remove bundled pkgs
rm -rf astropy/extern/configobj
rm -rf astropy/extern/ply
rm -rf cextern/expat
rm -rf cextern/wcslib

%generate_buildrequires
export ASTROPY_USE_SYSTEM_ALL=1
#(eatdirt) temporarilly disabled
#pyproject_buildrequires

%build
# Use cairo backend due to https://bugzilla.redhat.com/show_bug.cgi?id=1394975
export ASTROPY_USE_SYSTEM_ALL=1
#export MPLBACKEND=cairo
#(eatdirt) let's try with no-X backend (as Debian does)
export MPLBACKEND=agg
#(eatdirt) workaround the usual astropy crap...
export CFLAGS="%{optflags} -Wno-incompatible-pointer-types"
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name}

%files -n %{pypi_name}-tools
%{_bindir}/volint
%{_bindir}/fitscheck
%{_bindir}/fitsdiff
%{_bindir}/fitsheader
%{_bindir}/samp_hub
%{_bindir}/wcslint
%{_bindir}/fits2bitmap
%{_bindir}/fitsinfo
%{_bindir}/showtable

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.rst


%changelog
* Sat Dec 07 2024 eatdirt <eatdirt> 7.0.0-1.mga10
+ Revision: 2122521
- Upgrade to version 7.0.0

* Thu Sep 05 2024 eatdirt <eatdirt> 6.1.3-1.mga10
+ Revision: 2093240
- Update to version 6.1.3

* Mon Jun 03 2024 papoteur <papoteur> 6.1.0-2.mga10
+ Revision: 2069539
- relax requirement of astropy-tools

* Sun May 05 2024 eatdirt <eatdirt> 6.1.0-1.mga10
+ Revision: 2062343
- Upgrade to version 6.1.0

* Thu Mar 07 2024 papoteur <papoteur> 6.0.0-2.mga10
+ Revision: 2048316
- rebuild for python 3.12

* Sun Dec 24 2023 wally <wally> 6.0.0-1.mga10
+ Revision: 2021136
- new version 6.0.0
- use system ply and configobj
- add patch to fix linking
- use pyproject rpm macros

* Mon Nov 06 2023 joequant <joequant> 5.3.4-1.mga10
+ Revision: 2004860
- update to 5.3.4

* Sun Dec 04 2022 eatdirt <eatdirt> 5.1.1-1.mga9
+ Revision: 1917552
- Update to version 5.1.1
- Update to version 5.1.1

* Wed Oct 26 2022 papoteur <papoteur> 5.1-2.mga9
+ Revision: 1899511
- Rebuild for python-pytest-astropy-header

* Fri Aug 26 2022 eatdirt <eatdirt> 5.1-1.mga9
+ Revision: 1880533
- Upgrade to version 5.1

* Sat Apr 02 2022 umeabot <umeabot> 4.3.1-3.mga9
+ Revision: 1840999
- Mageia 9 Mass Rebuild

* Thu Feb 24 2022 mrambo3501 <mrambo3501> 4.3.1-2.mga9
+ Revision: 1783986
- rebuild for python-3.10

* Sun Sep 26 2021 joequant <joequant> 4.3.1-1.mga9
+ Revision: 1746408
- update to 4.3.1

* Sat Mar 20 2021 joequant <joequant> 4.2-2.mga9
+ Revision: 1705221
- update to python3.9

* Wed Dec 23 2020 eatdirt <eatdirt> 4.2-1.mga8
+ Revision: 1663142
- Upgrade to version 4.2

* Thu Jul 23 2020 daviddavid <daviddavid> 4.0.1-2.mga8
+ Revision: 1608173
- rebuild for new cfitsio 3.480

* Sun May 03 2020 joequant <joequant> 4.0.1-1.mga8
+ Revision: 1578519
- update to 4.0.1

* Fri Mar 27 2020 daviddavid <daviddavid> 3.2.1-4.mga8
+ Revision: 1560896
- rebuild for new cfitsio 3.470

* Sun Feb 16 2020 umeabot <umeabot> 3.2.1-3.mga8
+ Revision: 1534946
- Mageia 8 Mass Rebuild

* Mon Oct 07 2019 tv <tv> 3.2.1-2.mga8
+ Revision: 1450316
- build like FC, thus fixing build
- add some more BRs
- rebuild for python-3.8
- drop python2 subpkg

* Fri Aug 23 2019 joequant <joequant> 3.2.1-1.mga8
+ Revision: 1431502
- fix build
- add pkg-resources
- update to 3.2.1

* Thu May 23 2019 eatdirt <eatdirt> 3.1.2-4.mga7
+ Revision: 1398962
- Relax version check for python2-pytest

* Fri May 10 2019 eatdirt <eatdirt> 3.1.2-3.mga7
+ Revision: 1397139
- Rebuild for new python-pytest

* Wed Apr 17 2019 eatdirt <eatdirt> 3.1.2-2.mga7
+ Revision: 1392034
- Rebuild for new wcslib

* Wed Apr 17 2019 eatdirt <eatdirt> 3.1.2-1.mga7
+ Revision: 1391963
- Upgrade to latest py2 2.0.12 and py3 3.1.2 versions

* Mon Jan 07 2019 shlomif <shlomif> 3.1.1-1.mga7
+ Revision: 1351043
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 3.0.4-4.mga7
+ Revision: 1300441
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 eatdirt <eatdirt> 3.0.4-3.mga7
+ Revision: 1250756
- Fix eggs generation from astropy_helpers

* Wed Aug 08 2018 eatdirt <eatdirt> 3.0.4-2.mga7
+ Revision: 1250053
- Fix incorrect Requires

* Tue Aug 07 2018 eatdirt <eatdirt> 3.0.4-1.mga7
+ Revision: 1248699
- Upgrade to version 3.0.4

* Sun May 13 2018 daviddavid <daviddavid> 2.0.1-3.mga7
+ Revision: 1228742
- rebuild for new cfitsio 3.450
- use new python macros and provides

* Tue Aug 08 2017 daviddavid <daviddavid> 2.0.1-2.mga7
+ Revision: 1138796
- provides python-astropy

* Sun Aug 06 2017 joequant <joequant> 2.0.1-1.mga7
+ Revision: 1137878
- update to 2.0.1

* Sat Aug 05 2017 pterjan <pterjan> 1.3.2-2.mga7
+ Revision: 1135314
- Rebuild for python 3.6

* Mon May 29 2017 eatdirt <eatdirt> 1.3.2-1.mga6
+ Revision: 1105493
- Update to version 1.3.2

* Thu Dec 01 2016 eatdirt <eatdirt> 1.2.1-1.mga6
+ Revision: 1071457
- Upgrade to version 1.2.1

* Tue Nov 22 2016 eatdirt <eatdirt> 1.1.2-2.mga6
+ Revision: 1068812
- Rebuild for new cfitsio

* Fri Mar 11 2016 eatdirt <eatdirt> 1.1.2-1.mga6
+ Revision: 989216
- Upgrade to version 1.1.2
- Rebuilt for new cfitsio
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Oct 08 2015 eatdirt <eatdirt> 1.0.5-1.mga6
+ Revision: 887565
- Upgrade to version 1.0.5

* Tue Jul 14 2015 joequant <joequant> 1.0.3-1.mga6
+ Revision: 854021
- upgrade to 1.0.3

* Fri Feb 06 2015 joequant <joequant> 0.4.1-7.mga5
+ Revision: 813696
- bump number
- activate python3

* Fri Feb 06 2015 joequant <joequant> 0.4.1-6.mga5
+ Revision: 813690
- add system erfa line
- fix group
- add python3 code

* Fri Feb 06 2015 joequant <joequant> 0.4.1-5.mga5
+ Revision: 813645
- fix build
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps

* Sat Aug 30 2014 joequant <joequant> 0.4.1-1.mga5
+ Revision: 669399
- update to 0.4.1
+ pterjan <pterjan>
- Rebuild for new Python

* Thu Feb 27 2014 eatdirt <eatdirt> 0.2.4-5.mga5
+ Revision: 597702
- Rebuild for new cfitsio

* Tue Oct 22 2013 umeabot <umeabot> 0.2.4-4.mga4
+ Revision: 542906
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.2.4-3.mga4
+ Revision: 498127
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 04 2013 joequant <joequant> 0.2.4-2.mga4
+ Revision: 463155
- override binaries in python-stsci

* Fri Jul 26 2013 joequant <joequant> 0.2.4-1.mga4
+ Revision: 458558
- fix bindir
- update to 0.2.4 and fix cfitsio compatibility
- upgrade to 0.2.3
- imported package python-astropy

